# frozen_string_literal: true

module Bullet
  module Detector
    class Base
    end
  end
end
